package com.hzya.frame.voucher.ae.comf.subject.service.impl;

import cn.hutool.core.lang.Assert;
import com.hzya.frame.voucher.ae.comf.subject.dao.IAeConfSubjectContrastBDao;
import com.hzya.frame.voucher.ae.comf.subject.entity.AeConfSubjectClassificationEntity;
import com.hzya.frame.voucher.ae.comf.subject.dao.IAeConfSubjectClassificationDao;
import com.hzya.frame.voucher.ae.comf.subject.entity.AeConfSubjectContrastBEntity;
import com.hzya.frame.voucher.ae.comf.subject.entity.AeConfSubjectContrastEntity;
import com.hzya.frame.voucher.ae.comf.subject.service.IAeConfSubjectClassificationService;
import com.hzya.frame.voucher.ae.comf.subject.service.IAeConfSubjectContrastBService;
import org.springframework.stereotype.Service;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.Resource;

import com.hzya.frame.basedao.service.impl.BaseService;

import java.util.List;

/**
 * 会计事项(accounting_event)-配置-科目分类定义(AeConfSubjectClassification)表服务实现类
 *
 * @author zydd
 * @since 2025-06-06 17:00:57
 */
@Service
public class AeConfSubjectClassificationServiceImpl extends BaseService<AeConfSubjectClassificationEntity, String> implements IAeConfSubjectClassificationService {

    private IAeConfSubjectClassificationDao aeConfSubjectClassificationDao;

    @Autowired
    public void setAeConfSubjectClassificationDao(IAeConfSubjectClassificationDao dao) {
        this.aeConfSubjectClassificationDao = dao;
        this.dao = dao;
    }

    @Autowired
    private IAeConfSubjectContrastBService contrastBService;

    @Override
    public List<AeConfSubjectClassificationEntity> queryAll(AeConfSubjectClassificationEntity entity) {
        Assert.notNull(entity.getPkCorp(), "查询科目分类定义时，公司主键不允许为空。");
        Assert.notNull(entity.getPkglorgbook(), "查询科目分类定义时，账簿主键不允许为空。");
        Assert.notNull(entity.getAeConfModuleId(), "查询科目分类定义时，业务模块id不允许为空。");
        List<AeConfSubjectClassificationEntity> query = aeConfSubjectClassificationDao.query(entity);
        for (AeConfSubjectClassificationEntity aeConfSubjectClassificationEntity : query) {
            //查询科目对照子表
            queryaeConfSubjectContrastBList(aeConfSubjectClassificationEntity);
        }
        return query;
    }

    @Override
    public AeConfSubjectClassificationEntity queryById(AeConfSubjectClassificationEntity entity) {
        Assert.notNull(entity.getId(), "查询科目分类定义时，id不允许为空。");
        Assert.notNull(entity.getPkCorp(), "查询科目分类定义时，公司主键不允许为空。");
        Assert.notNull(entity.getPkglorgbook(), "查询科目分类定义时，账簿主键不允许为空。");
        Assert.notNull(entity.getAeConfModuleId(), "查询科目分类定义时，业务模块id不允许为空。");
        List<AeConfSubjectClassificationEntity> query = aeConfSubjectClassificationDao.query(entity);
        if (query.size() == 0 || query.size() > 1) {
            return null;
        }
        AeConfSubjectClassificationEntity aeConfSubjectClassificationEntity = query.get(0);
        //查询科目对照子表
        queryaeConfSubjectContrastBList(aeConfSubjectClassificationEntity);
        return aeConfSubjectClassificationEntity;
    }

    /**
     * 科目分类定义
     */
    @Override
    public AeConfSubjectClassificationEntity saveEntity(AeConfSubjectClassificationEntity entity) {
        Assert.notNull(entity.getPkCorp(), "科目分类定义新增时，公司主键不允许为空。");
        Assert.notNull(entity.getPkglorgbook(), "科目分类定义新增时，核算账簿id不允许为空。");
        Assert.notNull(entity.getAeConfModuleId(), "科目分类定义新增时，业务模块id不允许为空。");
        Assert.notNull(entity.getGlorgbookcode(), "科目分类定义新增时，核算账簿编码不允许为空。");
        Assert.notNull(entity.getGlorgbookname(), "科目分类定义新增时，核算账簿名称不允许为空。");
        Assert.notNull(entity.getCode(), "科目分类定义新增时，编码不允许为空。");
        Assert.notNull(entity.getName(), "科目分类定义新增时，名称不允许为空。");
        AeConfSubjectClassificationEntity save = aeConfSubjectClassificationDao.save(entity);
        //查询科目对照子表
        queryaeConfSubjectContrastBList(save);


        return save;
    }

    @Override
    public AeConfSubjectClassificationEntity updateEntity(AeConfSubjectClassificationEntity entity) {
        Assert.notNull(entity.getId(), "科目分类定义更新时，id不允许为空。");
        Assert.notNull(entity.getPkCorp(), "科目分类定义更新时，公司主键不允许为空。");
        Assert.notNull(entity.getAeConfModuleId(), "科目分类定义更新时，业务模块id不允许为空。");
        Assert.notNull(entity.getPkglorgbook(), "科目分类定义更新时，核算账簿id不允许为空。");
        Assert.notNull(entity.getGlorgbookcode(), "科目分类定义更新时，核算账簿编码不允许为空。");
        Assert.notNull(entity.getGlorgbookname(), "科目分类定义更新时，核算账簿名称不允许为空。");
        Assert.notNull(entity.getCode(), "科目分类定义更新时，编码不允许为空。");
        Assert.notNull(entity.getName(), "科目分类定义更新时，名称不允许为空。");
        AeConfSubjectClassificationEntity update = aeConfSubjectClassificationDao.update(entity);
        //查询科目对照子表
        queryaeConfSubjectContrastBList(update);
        return update;
    }

    @Override
    public void deleteEntity(AeConfSubjectClassificationEntity entity) {
        Assert.notNull(entity.getId(), "科目分类定义删除时，id不允许为空。");
        aeConfSubjectClassificationDao.logicRemove(entity);
    }


    public void queryaeConfSubjectContrastBList(AeConfSubjectClassificationEntity entity) {
        if (entity.getContrastId() != null && !"".equals(entity.getContrastId())) {
            //查询科目对照子表
            AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity = new AeConfSubjectContrastBEntity();
            aeConfSubjectContrastBEntity.setContrastId(Long.valueOf(entity.getContrastId()));
            List<AeConfSubjectContrastBEntity> bEntities = contrastBService.queryAllByContrastId(aeConfSubjectContrastBEntity);
            entity.setContrastBEntityList(bEntities);
        }
    }
}
